/*	Config.h
*
*	Application-specific configurations.
*
*	NOTE:
*	This file is included by the library code. Do not rename it!
*
*	Revisions:
*		10-16-06	DEBUG_ updates (from library change)
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#pragma once

/*
*	Resource Selection
*
*	These definitions select the resources (and timing) to be used
*	by the corresponding features (Timer, Motor, etc).
*
*	See individual class files (.h or .cpp) for details.
*/
#define CLOCK_8M		// uC clock at 8 MHz
#define TIMER_0			// Timer using Timer/Counter 0

/*
*	Debugging Options
*
*	There are a couple of options for showing errors (asserts)
*	-- using the serial port or the LCD; to enable either or
*	both, set the appropriate #define to the name of an object
*	created globally; comment out the line for no debug messages
*	of that method; you also need to make sure that the makefile's
*	DEFS line includes "-D DEBUG".
*
*	Usage:
*		Assert(<boolean condition that should be true>);
*		Debug(<statement to execute only in debug version>);
*	Example:
*		Assert(x < 16);		// this will show an error message if x >= 16
*		Debug(count = 0);	// this will only be compiled when using -D DEBUG
*/
/* these definitions control where Assert messages (for false conditions)
   and Log messages (see below) are sent */
//#define DEBUG_COMM g_comm		// send messages on serial connection
//#define DEBUG_COMM_TYPE COMM
//#define DEBUG_LCD g_lcd			// show messages on LCD
//#define DEBUG_LCD_TYPE LCD8

/*
*	Logging
*
*	Add "lgt" (LoG Type) values for different categories for which
*	you want to show messages. Set to 0 to disable messages.
*
*	Usage:
*		Log(<lgt value>, <string to show>);
*	Example:
*		Log(lgtMisc, "Hello, World!");
*		Log(lgtLine, "found line");
*/
const uint lgtMisc = 1;
const uint lgtWhatever = 0;
