/*	sound.h
*
*	Game Timer buzzer, uses Timer/Counter 1
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#pragma once

/* note: correlates with DIP values */
enum
{
	sndNil = 0,
	sndSiren,
	sndBeeps,
	sndTune,
};

struct NOTE
{
	ushort top;
	ushort dms;
};

class SOUND
{
public:
	SOUND();
	void SetVolume(uchar vol);	// 0 = quietest, 255 = loudest (although max expected is 160)
	void StartSound(uchar snd);
	void DoIdle();
	void Stop();
	inline bool FIdle() { return m_snd == sndNil; }

private:
	void StartNote();
	void StartOutput();
	void StopOutput();

	ushort m_vol;			// scale factor to apply to 'top' to get match value (numerator; denom = 2^16)
	uchar m_snd;			// which sound we're playing
	ulong m_msStart, m_dms;	// start, duration of current note
	union
	{
		struct	// sndTune
		{
			const NOTE *m_pnote;	// progmem
			uchar m_cnote;			// notes remaining (including currently playing)
		};
		struct	// sndBeeps
		{
			uchar m_cbeep;
		};
		struct	// sndSiren
		{
			ushort m_csiren;
			ushort m_top;
		};
	};
};
